// src/mariana.ts
import { EditorView } from "@codemirror/view";
import { HighlightStyle, syntaxHighlighting } from "@codemirror/language";
import { tags as t } from "@lezer/highlight";
var black = "hsl(0, 0%, 0%)";
var blue = "hsl(210, 50%, 60%)";
var blueVibrant = "hsl(210, 60%, 60%)";
var blue2 = "hsla(210, 13%, 40%, 0.7)";
var blue3 = "hsl(210, 15%, 22%)";
var blue4 = "hsl(210, 13%, 45%)";
var blue5 = "hsl(180, 36%, 54%)";
var blue6 = "hsl(221, 12%, 69%)";
var green = "hsl(114, 31%, 68%)";
var grey = "hsl(0, 0%, 20%)";
var yellow = "hsl(50, 100%, 60%)";
var orange = "hsl(32, 93%, 66%)";
var orange2 = "hsl(32, 85%, 55%)";
var orange3 = "hsl(40, 94%, 68%)";
var pink = "hsl(300, 30%, 68%)";
var red = "hsl(357, 79%, 65%)";
var red2 = "hsl(13, 93%, 66%)";
var white = "hsl(0, 0%, 100%)";
var white2 = "hsl(0, 0%, 97%)";
var white3 = "hsl(219, 28%, 88%)";
var blend = (a2, b, p) => `color-mix(in srgb, ${a2} ${p * 100}%, ${b})`;
var a = (color2, p) => blend(color2, "transparent", p);
var foreground = white3;
var background = blue3;
var accent = blueVibrant;
var caret = orange;
var lineHighlight = blue2;
var selection = blue2;
var selectionBorder = blue4;
var inactiveSelection = blue2;
var misspelling = red;
var shadow = a(black, 0.25);
var activeGuide = blue5;
var stackGuide = a(blue5, 0.5);
var highlight = blue5;
var findHighlightForeground = grey;
var findHighlight = orange3;
var bracketsOptions = "underline";
var bracketsForeground = orange;
var bracketsContentsOptions = "underline";
var bracketsContentsForeground = blue5;
var tagsOptions = "dotted";
var tagsForeground = pink;
var bg = blend(background, black, 0.6);
var link = "hsl(215, 60%, 50%)";
var divider = "hsl(0, 0%, 38%)";
var tooltip = blend(background, white, 0.95);
var color = {
  black,
  blue,
  blueVibrant,
  blue2,
  blue3,
  blue4,
  blue5,
  blue6,
  green,
  grey,
  yellow,
  orange,
  orange2,
  orange3,
  pink,
  red,
  red2,
  white,
  white2,
  white3,
  // Variables.
  foreground,
  background,
  accent,
  caret,
  lineHighlight,
  selection,
  selectionBorder,
  inactiveSelection,
  misspelling,
  shadow,
  activeGuide,
  stackGuide,
  highlight,
  findHighlightForeground,
  findHighlight,
  bracketsOptions,
  bracketsForeground,
  bracketsContentsOptions,
  bracketsContentsForeground,
  tagsOptions,
  tagsForeground,
  bg,
  link,
  divider,
  tooltip
};
var marianaTheme = EditorView.theme({
  "&": {
    color: white3,
    backgroundColor: blue3
  },
  ".cm-content": {
    caretColor: orange
  },
  ".cm-cursor, .cm-dropCursor": {
    borderLeftColor: orange,
    borderLeftWidth: "2px",
    marginLeft: "-1px"
  },
  "&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection": {
    backgroundColor: blue2,
    outline: color.selectionBorder
  },
  ".cm-panels": {
    backgroundColor: `hsl(from ${color.background} h s calc(l * 0.5))`
  },
  ".cm-searchMatch": {
    outline: `${color.highlight} solid 1px`,
    borderRadius: "2px",
    backgroundColor: "transparent"
  },
  ".cm-searchMatch.cm-searchMatch-selected": {
    outline: "none",
    backgroundColor: color.findHighlight,
    color: color.findHighlightForeground
  },
  ".cm-activeLine": {
    backgroundColor: "transparent"
  },
  ".cm-selectionMatch": {
    outline: `${color.highlight} solid 1px`,
    borderRadius: "2px",
    backgroundColor: "transparent"
  },
  "&.cm-focused .cm-matchingBracket, &.cm-focused .cm-nonmatchingBracket": {
    backgroundColor: "transparent",
    borderBottom: `1px solid ${color.bracketsForeground}`
  },
  ".cm-gutterElement": {
    width: "10px"
  },
  ".cm-gutters": {
    backgroundColor: color.background,
    color: a(color.foreground, 0.5),
    border: "none"
  },
  ".cm-activeLineGutter": {
    backgroundColor: color.lineHighlight,
    color: a(color.foreground, 0.9)
  },
  ".cm-foldPlaceholder": {
    backgroundColor: "transparent",
    border: "none",
    color: color.foreground
  },
  ".cm-tooltip": {
    border: "none",
    backgroundColor: tooltip,
    boxShadow: `0 2px 15px ${color.shadow}`
  },
  ".cm-tooltip .cm-tooltip-arrow:before": {
    borderTopColor: "transparent",
    borderBottomColor: "transparent"
  },
  ".cm-tooltip .cm-tooltip-arrow:after": {
    borderTopColor: tooltip,
    borderBottomColor: tooltip
  },
  ".cm-tooltip-autocomplete": {
    "& > ul": {
      scrollbarColor: `${divider} transparent`
    },
    "& > ul > li[aria-selected]": {
      backgroundColor: color.blue2
    }
  }
}, { dark: true });
var marianaHighlightStyle = HighlightStyle.define([
  { tag: [t.comment, t.separator, t.derefOperator], color: blue6 },
  { tag: [t.string], color: green },
  { tag: [t.function(t.name), t.typeName], color: blue },
  { tag: [t.angleBracket, t.definition(t.propertyName), t.function(t.definition(t.variableName))], color: blue5 },
  { tag: [t.number, t.definition(t.className)], color: orange },
  { tag: [t.self, t.bool, t.constant(t.name), t.special(t.name), t.tagName, t.operator], color: red },
  { tag: [t.keyword, t.escape, t.function(t.punctuation), t.processingInstruction, t.labelName, t.attributeName, t.className, t.namespace], color: pink },
  { tag: [t.special(t.brace)], color: white },
  { tag: [t.macroName], color: blue, fontStyle: "italic" },
  { tag: [t.link, t.url], color: blue, textDecoration: "underline" },
  { tag: [t.heading, t.strong], fontWeight: "bold" },
  { tag: [t.emphasis], fontStyle: "italic" },
  { tag: [t.strikethrough], textDecoration: "line-through" }
]);
var mariana = [marianaTheme, syntaxHighlighting(marianaHighlightStyle)];
export {
  color,
  mariana,
  marianaHighlightStyle,
  marianaTheme
};
